# Generated by Django 2.1.9 on 2019-06-12 08:20

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("terra_layer", "0008_auto_20190611_1323")]

    operations = [
        migrations.AlterField(
            model_name="filterfield",
            name="filter_settings",
            field=django.contrib.postgres.fields.jsonb.JSONField(default=dict),
        )
    ]
