# Generated by Django 2.1.9 on 2019-07-18 08:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("terra_layer", "0029_auto_20190716_1643")]

    operations = [
        migrations.AddField(
            model_name="layergroup", name="order", field=models.IntegerField(default=0)
        )
    ]
