# Generated by Django 2.0.13 on 2019-06-06 14:35

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("terra_layer", "0004_auto_20190605_1638")]

    operations = [
        migrations.AlterField(
            model_name="layer",
            name="layer_style",
            field=django.contrib.postgres.fields.jsonb.JSONField(
                blank=True, default={}
            ),
        )
    ]
