# Generated by Django 2.0.13 on 2019-07-04 08:12

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("terra_layer", "0023_layer_interactions")]

    operations = [
        migrations.AddField(
            model_name="customstyle",
            name="interactions",
            field=django.contrib.postgres.fields.jsonb.JSONField(default=list),
        )
    ]
