# Generated by Django 2.1.9 on 2019-07-15 14:31

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [("terra_layer", "0026_layer_group")]

    operations = [
        migrations.RemoveField(model_name="layer", name="view"),
        migrations.AlterField(
            model_name="layer",
            name="group",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="terra_layer.LayerGroup",
            ),
        ),
    ]
