# Generated by Django 2.2.5 on 2019-11-05 03:07

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("terra_layer", "0041_auto_20191003_1701")]

    operations = [
        migrations.AlterModelOptions(name="layer", options={"ordering": ("order",)}),
        migrations.AlterModelOptions(name="scene", options={}),
    ]
