# Generated by Django 2.1.11 on 2019-08-08 16:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("terra_layer", "0036_auto_20190731_1848")]

    operations = [
        migrations.AlterModelOptions(
            name="filterfield", options={"ordering": ("order",)}
        ),
        migrations.AddField(
            model_name="filterfield", name="order", field=models.IntegerField(default=0)
        ),
    ]
