# Generated by Django 2.1.10 on 2019-07-31 16:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [("terra_layer", "0035_auto_20190723_1418")]

    operations = [
        migrations.AlterModelOptions(
            name="layer",
            options={
                "ordering": ("order",),
                "permissions": (("can_manage_layers", "Can manage layers"),),
            },
        ),
        migrations.AlterField(
            model_name="layergroup",
            name="parent",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="children",
                to="terra_layer.LayerGroup",
            ),
        ),
    ]
