# Generated by Django 2.0.13 on 2019-06-11 09:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("terra_layer", "0006_auto_20190607_1151")]

    operations = [
        migrations.AlterField(
            model_name="layer",
            name="view",
            field=models.IntegerField(
                choices=[
                    (1, "Visualiser"),
                    (2, "Analyser"),
                    (3, "Découvrir les espaces d'activité"),
                ]
            ),
        )
    ]
