# Generated by Django 2.1.12 on 2019-09-24 09:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("terra_layer", "0039_layer_main_field")]

    operations = [
        migrations.AddField(
            model_name="filterfield",
            name="format_type",
            field=models.CharField(default=None, max_length=255, null=True),
        )
    ]
